@@ -184,7 +184,7 @@ class QreatorWindow(Window):   # pylint: disable=W0232
         about.set_website("http://davidplanella.org/project-showcase/qreator/")
 
         #FIXME: the version should be picked up from setup.py
-        about.set_version('13.05.3')
+        about.set_version('16.06.1')
         about.set_authors([
             'David Planella <david.planella@ubuntu.com>',
             'Stefan Schwarzburg <stefan.schwarzburg@googlemail.com>',
@@ -192,7 +192,8 @@ class QreatorWindow(Window):   # pylint: disable=W0232
             'Andrew Starr-Bochicchio <andrewsomething@ubuntu.com>',
             'Jef Spaleta <jspaleta@fedoraproject.org>',
             'Fong LH <fonglh@gmail.com>',
-            'Ilya Volchanetskiy <volchanetskiy@ukr.net>'
+            'Ilya Volchanetskiy <volchanetskiy@ukr.net>',
+            'Felix Eckhofer <felix@eckhofer.com>'
             ])
         about.set_license(_('Distributed under the GPL v3 license.') +
                 '\nhttp://www.opensource.org/licenses/gpl-3.0.html')
